@@ -14,6 +14,7 @@ use crate::key::Key;
 use crate::config::Config;
 use crate::ui::Flags;
 use crate::serialize;
+use crate::style::{Style, Stroke};
 
 #[derive(Copy,Clone,Debug, PartialEq, Eq)]
 /// Describes the possible states of the undo_queue and a pointer that moves
@@ -94,6 +95,8 @@ pub struct Pizarra {
     board_state: BoardState,
     selected_tool: SelectedTool,
     current_shape: Option<Box<dyn ShapeBuilder>>,
+    last_mouse_pos: Vec2DScreen,
+    eraser_is_active: bool,
 
     /// Some paremeters used during drawing
     selected_color: Color,
@@ -153,7 +156,13 @@ impl Pizarra {
                 if let Some(shape) = self.current_shape.as_mut() {
                     shape.handle_button_pressed(point, self.transform, self.config.point_snap_radius);
                 } else {
-                    let new_shape = shape.start(self.selected_color, transformed_point, self.transform.to_world_units(self.stroke));
+                    let new_shape = shape.start(transformed_point, Style {
+                        stroke: Some(Stroke {
+                            size: self.transform.to_world_units(self.stroke),
+                            color: self.selected_color,
+                        }),
+                        fill: None,
+                    });
 
                     self.current_shape = Some(new_shape);
                 }
@@ -166,6 +175,8 @@ impl Pizarra {
                     .map(|id| self.storage.remove(id))
                     .flatten();
 
+                self.eraser_is_active = true;
+
                 if let Some(shape) = deleted_shape {
                     self.erased.push(shape);
 
@@ -204,6 +215,8 @@ impl Pizarra {
                     .map(|id| self.storage.remove(id))
                     .flatten();
 
+                self.eraser_is_active = false;
+
                 if let Some(shape) = deleted_shape {
                     self.erased.push(shape);
                 }
@@ -329,6 +342,8 @@ impl Pizarra {
             current_shape: None,
 
             selected_tool: SelectedTool::Shape(ShapeTool::Path),
+            last_mouse_pos: dimensions / 2.0,
+            eraser_is_active: false,
             bgcolor: config.background_color,
             stroke: config.thickness,
             selected_color: config.stroke_color,
@@ -398,6 +413,34 @@ impl Pizarra {
         self.storage.draw_commands(bbox)
     }
 
+    pub fn draw_commands_for_tool(&self) -> Vec<DrawCommand> {
+        if let SelectedTool::Eraser = self.selected_tool {
+            vec![
+                DrawCommand::ScreenCircle {
+                    center: self.last_mouse_pos,
+                    radius: self.erase_radius,
+                    style: Style {
+                        stroke: Some(Stroke {
+                            size: 1.0,
+                            color: if self.eraser_is_active {
+                                Color::red()
+                            } else {
+                                Color::gray()
+                            },
+                        }),
+                        fill: if self.eraser_is_active {
+                            Some(Color::red().half_transparent())
+                        } else {
+                            None
+                        },
+                    },
+                }
+            ]
+        } else {
+            vec![]
+        }
+    }
+
     /// returns only the draw commands needed to paint the current shape on the
     /// screen.
     pub fn draw_commands_for_current_shape(&self) -> Option<Vec<DrawCommand>> {
@@ -558,6 +601,7 @@ impl Pizarra {
         };
 
         self.board_state = new_board_state;
+        self.last_mouse_pos = pos;
 
         should_redraw
     }
@@ -745,11 +789,14 @@ impl Pizarra {
 
 #[cfg(test)]
 mod tests {
-    use super::*;
     use crate::{
         draw_commands::DrawCommand, app::SelectedTool,
         path_command::{PathCommand, CubicBezierCurve},
     };
+    use crate::style::{Style, Stroke};
+
+    use super::*;
+
     use PathCommand::*;
 
     #[test]
@@ -767,8 +814,13 @@ mod tests {
         let commands = app.draw_commands_for_screen();
 
         assert_eq!(commands[0], DrawCommand::Path {
-            color: Some(Default::default()),
-            fill: None,
+            style: Style {
+                stroke: Some(Stroke {
+                    color: Default::default(),
+                    size: Config::default().thickness,
+                }),
+                fill: None,
+            },
             commands: vec![
                 MoveTo(Vec2DWorld { x: -40.0, y: -30.0 }),
                 CurveTo(CubicBezierCurve {
@@ -777,7 +829,6 @@ mod tests {
                     to: Vec2DWorld { x: -39.0, y: -30.0 }
                 }),
             ],
-            thickness: Config::default().thickness,
         });
     }
 
@@ -798,8 +849,13 @@ mod tests {
         let commands = app.draw_commands_for_screen();
 
         assert_eq!(commands[0], DrawCommand::Path {
-            color: Some(Default::default()),
-            fill: None,
+            style: Style {
+                stroke: Some(Stroke {
+                    color: Default::default(),
+                    size: Config::default().thickness / 2.0,
+                }),
+                fill: None,
+            },
             commands: vec![
                 MoveTo(Vec2DWorld { x: -20.0, y: -15.0 }),
                 CurveTo(CubicBezierCurve {
@@ -808,7 +864,6 @@ mod tests {
                     to: Vec2DWorld { x: -19.5, y: -15.0 }
                 }),
             ],
-            thickness: Config::default().thickness / 2.0,
         });
     }
 
@@ -841,7 +896,9 @@ mod tests {
         app.resize(Vec2DScreen::new(4.0, 4.0));
 
         app.set_tool(SelectedTool::Shape(ShapeTool::Path));
+        app.set_stroke(0.0);
 
+        // draw the shape
         app.handle_mouse_button_pressed(MouseButton::Left, Vec2DScreen::new(2.0, 1.0));
         app.handle_mouse_move(Vec2DScreen::new(2.0, 1.5));
         app.handle_mouse_move(Vec2DScreen::new(2.0, 2.0));
@@ -855,6 +912,7 @@ mod tests {
         app.set_tool(SelectedTool::Eraser);
         app.set_erase_radius(0.5);
 
+        // attempt erase and fail
         app.handle_mouse_button_pressed(MouseButton::Left, Vec2DScreen::new(2.6, 0.0));
         app.handle_mouse_move(Vec2DScreen::new(2.6, 1.0));
         app.handle_mouse_move(Vec2DScreen::new(2.6, 3.0));
@@ -862,6 +920,7 @@ mod tests {
 
         assert_eq!(app.storage.shape_count(), 1);
 
+        // attempt erase and succeed
         app.handle_mouse_button_pressed(MouseButton::Left, Vec2DScreen::new(2.24, 0.0));
         app.handle_mouse_move(Vec2DScreen::new(2.4, 1.0));
         app.handle_mouse_move(Vec2DScreen::new(2.4, 3.0));
@@ -1026,9 +1085,7 @@ mod tests {
         assert_eq!(commands.len(), 1);
 
         assert_eq!(commands[0], DrawCommand::Path {
-            color: Some(Default::default()),
-            fill: None,
-            thickness: Config::default().thickness,
+            style: Default::default(),
             commands: vec![
                 MoveTo(Vec2DWorld { x: -30.0, y: -20.0 }),
                 CurveTo(CubicBezierCurve {
