@@ -1,13 +1,27 @@
 #![allow(non_snake_case)]
 //! All sorts of geometrical functions, constants and procedures
-use std::ops::Mul;
+use std::ops::{Mul, Neg};
 
 use crate::point::{Point, Vec2DWorld};
+use crate::transform::Transform;
 
+/// How many points will be used to approximate the bezier curve for the purpose
+/// of erasing a shape.
+///
+/// Too few will yield poor results (shapes not being deleted when the user
+/// expects them to or shapes being deleted event before being touched).
+/// Too many will impact performance.
+const BEZIER_PARTS: usize = 50;
+
+/// Stores the angle in radians internally
 #[derive(Copy, Clone, Debug, Default, PartialEq)]
 pub struct Angle(f64);
 
 impl Angle {
+    pub fn is_zero(self) -> bool {
+        self.0 == 0.0
+    }
+
     pub fn degrees(self) -> f64 {
         self.0.to_degrees()
     }
@@ -47,6 +61,14 @@ impl Mul<f64> for Angle {
     }
 }
 
+impl Neg for Angle {
+    type Output = Self;
+
+    fn neg(self) -> Self {
+        Angle(-self.0)
+    }
+}
+
 fn dot<P: Point>(a: P, b: P) -> f64 {
     a.x() * b.x() + a.y() * b.y()
 }
@@ -133,11 +155,13 @@ fn bezier_intersects_circle_inner<P: Point>(from: P, p1: P, p2: P, to: P, center
         return true;
     }
 
+    let piece = 1.0 / BEZIER_PARTS as f64;
+
     // here we compute 10 curve's points. This should be a good enough
     // aproximation
-    let points: Vec<_> = IntoIterator::into_iter([
-        0.0, 0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9, 1.0,
-    ]).map(|t| {
+    let points: Vec<_> = (0..BEZIER_PARTS).map(|p| {
+        p as f64 * piece
+    }).map(|t| {
         let b1 = combine(from, p1, t);
         let b2 = combine(p1, p2, t);
         let b3 = combine(p2, to, t);
@@ -275,9 +299,132 @@ pub fn mirror<P: Point>(point: P, through: P) -> P {
     through + c
 }
 
+fn robust_length(a: f64, b: f64) -> f64 {
+    if a.abs() > b.abs() {
+        a.abs() * (1.0 + (b/a).powi(2)).sqrt()
+    } else {
+        b.abs() * (1.0 + (a/b).powi(2)).sqrt()
+    }
+}
+
+const MAX_ITERATIONS: usize = 1074;
+
+/// from https://www.geometrictools.com/Documentation/DistancePointEllipseEllipsoid.pdf
+/// David Eberly, Geometric Tools, Redmond WA 98052
+fn get_root(r0: f64, z0: f64, z1: f64, mut g: f64) -> f64 {
+    let n0 = r0 * z0;
+    let mut s0 = z1 - 1.0;
+    let mut s1 = if g < 0.0 { 0.0 } else { robust_length(n0, z1) - 1.0 };
+    let mut s = 0.0;
+
+    for _ in 0..MAX_ITERATIONS {
+        s = ( s0 + s1 ) / 2.0;
+
+        if s == s0 || s == s1 {
+            break;
+        }
+
+        let ratio0 = n0 / ( s + r0 );
+        let ratio1 = z1 / ( s + 1.0 );
+
+        g = ratio0.powi(2) + ratio1.powi(2) - 1.0;
+
+        if g > 0.0 {
+            s0 = s;
+        } else if g < 0.0 {
+            s1 = s;
+        } else {
+            break;
+        }
+    }
+
+    s
+}
+
+/// from https://www.geometrictools.com/Documentation/DistancePointEllipseEllipsoid.pdf
+/// David Eberly, Geometric Tools, Redmond WA 98052
+///
+/// computes the distance from an ellipse to the given point. The ellipse is
+/// centered in the origin. The point's coordinates must be in the 1st cuadrant
+/// i.e. y0, y1 >= 0. The ellipse's longer axis e0 is along the x axis. It is
+/// assumed that e0 >= e1.
+fn distance_point_ellipse(e0: f64, e1: f64, y0: f64, y1: f64) -> ((f64, f64), f64) {
+    assert!(y0 >= 0.0);
+    assert!(y1 >= 0.0);
+    assert!(e0 >= e1);
+
+    if y1 > 0.0 {
+        if y0 > 0.0 {
+            let z0 = y0 / e0;
+            let z1 = y1 / e1;
+            // the ellipse equation
+            let g = z0.powi(2) + z1.powi(2) - 1.0;
+
+            if g != 0.0 {
+                let r0 = ( e0 / e1 ).powi(2);
+                let sbar = get_root(r0, z0, z1, g);
+                let x0 = r0 * y0 / ( sbar + r0 );
+                let x1 = y1 / (sbar + 1.0) ;
+                (
+                    (x0, x1),
+                    ((x0 - y0).powi(2) + (x1 - y1).powi(2)).sqrt()
+                )
+            } else {
+                // the given point satisfies the ellipse equation, then the
+                // distance is 0.0
+                let x0 = y0;
+                let x1 = y1;
+                ((x0, x1), 0.0)
+            }
+        } else { // y0 == 0
+            let x0 = 0.0;
+            let x1 = e1;
+            ((x0, x1), (y1 - e1).abs())
+        }
+    } else { // y1 == 0
+        let numer0 = e0 * y0;
+        let denom0 = ( e0 ).powi(2) - ( e1 ).powi(2);
+
+        if numer0 < denom0 {
+            let xde0 = numer0 / denom0;
+            let x0 = e0 * xde0;
+            let x1 = e1 * (1.0 - xde0 * xde0).sqrt();
+            ((x0, x1), ((x0 - y0).powi(2) + x1.powi(2)).sqrt())
+        } else {
+            let x0 = e0;
+            let x1 = 0.0;
+            ((x0, x1), (y0 - e0).abs())
+        }
+    }
+}
+
+/// An ellipse for geometrical purposes
+#[derive(Debug, Copy, Clone, PartialEq)]
+pub struct Ellipse<P> {
+    pub center: P,
+    pub semimajor: f64,
+    pub semiminor: f64,
+    pub angle: Angle,
+}
+
+pub fn distance_from_point_to_ellipse<P: Point>(point: P, ellipse: Ellipse<P>) -> f64 {
+    let point = Transform::default()
+        .translate((-ellipse.center).to_vec2d())
+        .rotate(-ellipse.angle)
+        .apply(point.to_vec2d());
+
+    // now make sure the point is in the first quadrant. This is a
+    // requirement of the algorithm and it is easy to see through symetries
+    // that it doesn't affect the result
+    let point = point.abs();
+    let (_closest_point, distance) = distance_point_ellipse(ellipse.semimajor, ellipse.semiminor, point.x, point.y);
+
+    distance
+}
+
 #[cfg(test)]
 mod tests {
-    use crate::point::Vec2DScreen;
+    use crate::point::{Vec2DScreen, Vec2D};
 
     use super::*;
 
@@ -437,4 +584,35 @@ mod tests {
 
         assert_eq!(mirror(j, i), (140.0, 80.0).into());
     }
+
+    #[test]
+    fn distance_to_ellipse() {
+        let ellipse = Ellipse {
+            center: Vec2D::new(-4.08, 3.07),
+            semimajor: 3.05,
+            semiminor: 2.03,
+            angle: Angle::from_degrees(24.09),
+        };
+
+        let points = [
+            ('G', (0.0, 3.0), 1.27),
+            ('H', (-9.0, 3.0), 2.06),
+            ('I', (-4.0, 6.0), 0.77),
+            ('J', (-4.0, -4.0), 4.89),
+            ('K', (-3.0, 3.0), 1.37),
+            ('L', (-6.0, 3.0), 0.8),
+            ('M', (-4.06, 1.34), 0.39),
+            ('N', (-3.34, 4.9), 0.4),
+        ];
+
+        for (name, coords, expected) in points {
+            let distance = distance_from_point_to_ellipse(coords.into(), ellipse);
+
+            assert!(
+                (distance - expected).abs() < 0.01,
+                "Failed for point {}. Distance: {}, expected: {}",
+                name, distance, expected,
+            );
+        }
+    }
 }
