@@ -224,26 +224,27 @@ impl <'a> Iterator for ShapeIterator<'a> {
 
 #[cfg(test)]
 mod tests {
-    use super::*;
+    use pretty_assertions::assert_eq;
 
-    use crate::shape::{
-        ShapeId,
-        circle::Circle, path::Path,
-    };
+    use crate::shape::{ShapeId, stored::{path::Path, ellipse::Ellipse}};
     use crate::path_command::PathCommand;
     use crate::color::Color;
     use crate::draw_commands::DrawCommand;
     use crate::point::Vec2DWorld;
+    use crate::geom::Angle;
+    use crate::style::{Style, Stroke};
+
+    use super::*;
 
     #[test]
     fn add_shapes_at_zoom() {
         let mut storage = Storage::new();
         let shapes: Vec<Box<dyn ShapeStored>> = vec![
-            Box::new(Circle::from_parts(Vec2DWorld::new(0.0, 0.0), 1.0, 1.0, Color::green())),
+            Box::new(Ellipse::from_parts(Vec2DWorld::new(0.0, 0.0), 1.0, 1.0, Angle::from_radians(0.0), Default::default())),
             Box::new(Path::from_parts(vec![
                 PathCommand::MoveTo(Vec2DWorld::new(0.0, 0.0)),
                 PathCommand::LineTo(Vec2DWorld::new(1.0, 1.0)),
-            ], Some(Color::red()), None, 1.0)),
+            ], Default::default())),
         ];
         let ids: Vec<_> = shapes.into_iter().map(|shape| {
             storage.add(shape)
@@ -264,7 +265,13 @@ mod tests {
             PathCommand::LineTo(Vec2DWorld::new(1.0, 0.0)),
             PathCommand::LineTo(Vec2DWorld::new(1.0, 1.0)),
             PathCommand::LineTo(Vec2DWorld::new(0.0, 1.0)),
-        ], Some(Color::green()), None, 1.0);
+        ], Style {
+            stroke: Some(Stroke {
+                size: 0.0,
+                color: Default::default(),
+            }),
+            fill: None,
+        });
 
         storage.add(Box::new(line));
 
@@ -283,11 +290,11 @@ mod tests {
         let obj_to_remove = Box::new(Path::from_parts(vec![
             PathCommand::MoveTo(Vec2DWorld::new(0.0, 0.0)),
             PathCommand::LineTo(Vec2DWorld::new(1.0, 0.0)),
-        ], Some(Color::green()), None, 1.0));
+        ], Default::default()));
         let obj_to_interfere = Box::new(Path::from_parts(vec![
             PathCommand::MoveTo(Vec2DWorld::new(0.0, 0.0)),
             PathCommand::LineTo(Vec2DWorld::new(1.0, 0.0)),
-        ], Some(Color::green()), None, 1.0));
+        ], Default::default()));
 
         let id_to_remove = storage.add(obj_to_remove);
         let _id_to_interfere = storage.add(obj_to_interfere);
@@ -310,11 +317,11 @@ mod tests {
         let obj_to_remove = Box::new(Path::from_parts(vec![
             PathCommand::MoveTo(Vec2DWorld::new(0.0, 0.0)),
             PathCommand::LineTo(Vec2DWorld::new(1.0, 0.0)),
-        ], Some(Color::green()), None, 1.0));
+        ], Default::default()));
         let obj_to_interfere = Box::new(Path::from_parts(vec![
             PathCommand::MoveTo(Vec2DWorld::new(0.0, 0.0)),
             PathCommand::LineTo(Vec2DWorld::new(1.0, 0.0)),
-        ], Some(Color::green()), None, 1.0));
+        ], Default::default()));
 
         let _id_to_interfere = storage.add(obj_to_interfere);
         let id_to_remove = storage.add(obj_to_remove);
@@ -336,22 +343,20 @@ mod tests {
         storage.add(Box::new(Path::from_parts(vec![
             PathCommand::MoveTo(Vec2DWorld::new(0.0, 0.0)),
             PathCommand::LineTo(Vec2DWorld::new(1.0, 0.0)),
-        ], Some(Color::green()), None, 4.0)));
+        ], Default::default())));
         let id = storage.add(Box::new(Path::from_parts(vec![
             PathCommand::MoveTo(Vec2DWorld::new(0.0, 1.0)),
             PathCommand::LineTo(Vec2DWorld::new(1.0, 1.0)),
-        ], Some(Color::green()), None, 4.0)));
+        ], Default::default())));
 
         storage.remove(id);
 
         assert_eq!(storage.draw_commands(bbox), vec![DrawCommand::Path {
-            color: Some(Color::green()),
-            fill: None,
+            style: Default::default(),
             commands: vec![
                 PathCommand::MoveTo(Vec2DWorld::new(0.0, 0.0)),
                 PathCommand::LineTo(Vec2DWorld::new(1.0, 0.0)),
             ],
-            thickness: 4.0,
         }]);
     }
 
@@ -366,19 +371,19 @@ mod tests {
                 PathCommand::LineTo(Vec2DWorld::new(-1.1, 1.1)),
                 PathCommand::LineTo(Vec2DWorld::new(1.1, 1.1)),
                 PathCommand::LineTo(Vec2DWorld::new(1.1, -1.1)),
-            ], Some(Color::green()), None, 1.0)),
+            ], Default::default())),
             Box::new(Path::from_parts(vec![
                 PathCommand::MoveTo(Vec2DWorld::new(-1.5, 0.5)),
                 PathCommand::LineTo(Vec2DWorld::new(-1.5, 0.5)),
                 PathCommand::LineTo(Vec2DWorld::new(-0.5, 1.5)),
                 PathCommand::LineTo(Vec2DWorld::new(-0.5, 1.5)),
-            ], Some(Color::green()), None, 1.0)),
+            ], Default::default())),
             Box::new(Path::from_parts(vec![
                 PathCommand::MoveTo(Vec2DWorld::new(0.25, -0.5)),
                 PathCommand::LineTo(Vec2DWorld::new(0.25, -0.5)),
                 PathCommand::LineTo(Vec2DWorld::new(0.5, -0.25)),
                 PathCommand::LineTo(Vec2DWorld::new(0.5, -0.25)),
-            ], Some(Color::green()), None, 1.0)),
+            ], Default::default())),
 
             // in red the ones that dont
             Box::new(Path::from_parts(vec![
@@ -386,7 +391,13 @@ mod tests {
                 PathCommand::LineTo(Vec2DWorld::new(20.0, 20.0)),
                 PathCommand::LineTo(Vec2DWorld::new(20.0, 20.0)),
                 PathCommand::LineTo(Vec2DWorld::new(20.0, 20.0)),
-            ], Some(Color::red()), None, 1.0)),
+            ], Style {
+                stroke: Some(Stroke {
+                    color: Color::red(),
+                    size: 1.0,
+                }),
+                fill: None,
+            })),
         ];
 
         for shape in shapes.into_iter() {
@@ -397,7 +408,7 @@ mod tests {
 
         assert_eq!(buffer.len(), 3);
 
-        buffer.iter().for_each(|x| assert_eq!(x.color(), Some(Color::green())));
+        buffer.iter().for_each(|x| assert_eq!(x.color(), Some(Color::default())));
     }
 
     #[test]
@@ -409,15 +420,15 @@ mod tests {
             PathCommand::LineTo(Vec2DWorld::new(1.0, 1.0)),
             PathCommand::LineTo(Vec2DWorld::new(1.0, 1.0)),
             PathCommand::LineTo(Vec2DWorld::new(1.0, 1.0)),
-        ], Default::default(), None, 1.0)));
+        ], Default::default())));
         storage.add(Box::new(Path::from_parts(vec![
             PathCommand::MoveTo(Vec2DWorld::new(5.0, 5.0)),
             PathCommand::LineTo(Vec2DWorld::new(1.0, 1.0)),
             PathCommand::LineTo(Vec2DWorld::new(1.0, 1.0)),
             PathCommand::LineTo(Vec2DWorld::new(1.0, 1.0)),
-        ], Default::default(), None, 1.0)));
+        ], Default::default())));
 
-        assert_eq!(storage.get_bounds(), Some([Vec2DWorld::new(-5.0, -5.0), Vec2DWorld::new(5.0, 5.0)]));
+        assert_eq!(storage.get_bounds(), Some([Vec2DWorld::new(-7.0, -7.0), Vec2DWorld::new(7.0, 7.0)]));
     }
 
     #[test]
@@ -427,17 +438,17 @@ mod tests {
         storage.add(Box::new(Path::from_parts(vec![
             PathCommand::MoveTo(Vec2DWorld::new(0.0, 0.0)),
             PathCommand::LineTo(Vec2DWorld::new(0.0, 2.0)),
-        ], Some(Color::red()), None, 4.0)));
+        ], Style::red_line())));
         storage.add(Box::new(Path::from_parts(vec![
             PathCommand::MoveTo(Vec2DWorld::new(0.0, 0.0)),
             PathCommand::LineTo(Vec2DWorld::new(0.0, 1.0)),
-        ],Some(Color::green()),  None, 4.0)));
+        ], Default::default())));
 
         let commands = storage.draw_commands([Vec2DWorld::new(-1.0, -1.0), Vec2DWorld::new(1.0, 3.0)]);
 
         assert_eq!(commands.len(), 2);
 
         assert_eq!(commands[0].color(), Some(Color::red()));
-        assert_eq!(commands[1].color(), Some(Color::green()));
+        assert_eq!(commands[1].color(), Some(Default::default()));
     }
 }
